@@ -9,7 +9,7 @@ likelihood.code.binom <- list(
   read.template("gemtc.likelihood.binom.txt"),
   read.template("gemtc.likelihood.binom.power.txt"))
 
-deviance.binom <- function(data, val, alpha=1) {
+deviance_fn.binom <- function(data, val, alpha=1) {
   r <- data$r
   n <- data$n
   rfit <- val
@@ -22,7 +22,7 @@ likelihood.code.poisson <- list(
   read.template("gemtc.likelihood.poisson.txt"),
   read.template("gemtc.likelihood.poisson.power.txt"))
 
-deviance.poisson <- function(data, val, alpha=1) {
+deviance_fn.poisson <- function(data, val, alpha=1) {
   r <- data$r
   rfit <- val
   2 * alpha * ((rfit - r) + fixna(r * log(r / rfit), 0))
@@ -34,7 +34,7 @@ likelihood.code.normal <- list(
   read.template("gemtc.likelihood.normal.txt"),
   read.template("gemtc.likelihood.normal.power.txt"))
 
-deviance.normal <- function(data, val, alpha=1) {
+deviance_fn.normal <- function(data, val, alpha=1) {
   alpha * (data$m - val)^2 / data$e^2
 }
 
