@@ -1,7 +1,7 @@
 context("relative.effect and rank.probability")
 
 test_that("relative.effect outputs the correct parameters", {
-  result <- dget(system.file("extdata/luades-smoking.samples.gz", package="gemtc"))
+  result <- readRDS(system.file("extdata/luades-smoking-samples.rds", package="gemtc"))
 
   expect_that(colnames(result$samples[[1]]), equals(c("d.A.B", "d.A.C", "d.A.D", "sd.d")))
 
@@ -25,7 +25,7 @@ test_that("relative.effect outputs the correct parameters", {
 })
 
 test_that("relative.effect generates the expected statistics", {
-  result <- dget(system.file("extdata/luades-smoking.samples.gz", package="gemtc"))
+  result <- readRDS(system.file("extdata/luades-smoking-samples.rds", package="gemtc"))
   stats <- summary(relative.effect(result, "B"))$summaries
 
   expected <- textConnection('
@@ -75,7 +75,7 @@ test_that("tree.relative.effect handles two-treatment case", {
 })
 
 test_that("relative.effect can be applied recursively", {
-  result <- dget(system.file("extdata/luades-smoking.samples.gz", package="gemtc"))
+  result <- readRDS(system.file("extdata/luades-smoking-samples.rds", package="gemtc"))
   result <- relative.effect(result, "C")
   stats <- summary(relative.effect(result, "B"))$summaries
 
@@ -99,12 +99,12 @@ test_that("rank.probability returns the right results", {
                         .Dim = c(4L, 4L),
                         .Dimnames = list(c("A", "B", "C", "D"), NULL),
                         class = "mtc.rank.probability", direction = 1)
-  result <- dget(system.file("extdata/luades-smoking.samples.gz", package="gemtc"))
+  result <- readRDS(system.file("extdata/luades-smoking-samples.rds", package="gemtc"))
   expect_that(rank.probability(result), equals(expected))
 })
 
 test_that("rank.probability can be applied to a subset of parameters", {
-  result <- dget(system.file("extdata/luades-smoking.samples.gz", package="gemtc"))
+  result <- readRDS(system.file("extdata/luades-smoking-samples.rds", package="gemtc"))
   result <- relative.effect(result, "A", c("B", "C"))
   rank.probability(result)
   succeed()
@@ -118,7 +118,7 @@ test_that("relative.effect.tree throws an error if requested comparison is not c
 })
 
 test_that("spanning.tree.mtc.result handles two-treatment case", {
-  result <- dget(system.file("extdata/luades-smoking.samples.gz", package="gemtc"))
+  result <- readRDS(system.file("extdata/luades-smoking-samples.rds", package="gemtc"))
   result <- relative.effect(result, t1="A", t2="B")
   
   g <- graph.edgelist(matrix(c("A", "B"), ncol=2))
@@ -131,7 +131,7 @@ test_that("spanning.tree.mtc.result handles two-treatment case", {
 })
 
 test_that("relative.effect is robust to missing sd.d", {
-  result <- dget(system.file("extdata/luades-smoking.samples.gz", package="gemtc"))
+  result <- readRDS(system.file("extdata/luades-smoking-samples.rds", package="gemtc"))
 
   out <- relative.effect(result, "A", preserve.extra=FALSE)
   expect_that(colnames(out$samples[[1]]), equals(c("d.A.B", "d.A.C", "d.A.D"))) #2
@@ -141,7 +141,7 @@ test_that("relative.effect is robust to missing sd.d", {
 })
 
 test_that("relative.effect is robust to leading columns", {
-  result <- dget(system.file("extdata/luades-smoking.samples.gz", package="gemtc"))
+  result <- readRDS(system.file("extdata/luades-smoking-samples.rds", package="gemtc"))
   leading <- matrix(rep(255,nrow(result[['samples']][[1]])), dimnames=list(NULL, "deviance"))
   for (i in 1:4) {
     result[['samples']][[i]] <- as.mcmc(cbind(leading, result[['samples']][[i]]))
